Learn R Programming

mudata2 (version 1.1.3)

alta_lake: Alta Lake Gravity Core Data

Description

Bulk geochemistry of a gravity core from Alta Lake, Whistler, British Columbia, Canada.

Usage

alta_lake

Arguments

Format

A mudata object

References

Dunnington DW, Spooner IS, White CE, et al (2016) A geochemical perspective on the impact of development at Alta Lake, British Columbia, Canada. J Paleolimnol 56:315-330. doi:10.1007/s10933-016-9919-x

Examples

Run this code
print(alta_lake)

Run the code above in your browser using DataLab