Learn R Programming

mudata2 (version 1.1.3)

rename_cols_base: Rename a column in an object

Description

Rename columns in a data frame or list

Usage

rename_cols_base(.data, ..., warn_missing = TRUE, warn_duplicated = TRUE)

# S3 method for default rename_cols_base(.data, ..., warn_missing = TRUE, warn_duplicated = TRUE)

Value

A copy of the modified object

Arguments

.data

An object that has columns that can be renamed

...

Key/value pairs to replace in the form oldval="newval"

warn_missing

Print a message if any old names are not actually present in x

warn_duplicated

Print a message if any name appears more than once in x after the operation.