Learn R Programming

mudata2 (version 1.1.3)

rename_datasets_base: Rename datasets, params, locations, and columns

Description

Provides a convenient way to rename datasets, params, locations, and columns such that their usage with a mudata object remains consistent.

Usage

rename_datasets_base(
  md,
  ...,
  apply_to = c("data", "locations", "params", "datasets", "columns"),
  warn_missing = TRUE
)

rename_params_base( md, ..., apply_to = c("data", "params"), warn_missing = TRUE )

rename_locations_base( md, ..., apply_to = c("data", "locations"), warn_missing = TRUE )

# S3 method for mudata rename_cols_base( .data, ..., apply_to = c("datasets", "locations", "params", "data", "columns"), warn_missing = FALSE, warn_duplicated = TRUE )

Value

A modified mudata object.

Arguments

md

A mudata object

...

Key/value pairs in the form "oldvalue"="newvalue"

apply_to

The tables which the rename operation should consider

warn_missing

Print a message if any old names are not actually present

.data

A mudata object

warn_duplicated

Print a message if any name appears more than once in x after the operation.