Rename columns in a data frame or list
rename_cols_base(.data, ..., warn_missing = TRUE, warn_duplicated = TRUE)# S3 method for default
rename_cols_base(.data, ..., warn_missing = TRUE, warn_duplicated = TRUE)
A copy of the modified object
An object that has columns that can be renamed
Key/value pairs to replace in the form oldval="newval"
Print a message if any old names are not actually present in x
Print a message if any name appears more than once in x after the operation.