Provides a convenient way to rename datasets, params, locations, and columns such that their usage with a mudata object remains consistent.
rename_datasets_base(
md,
...,
apply_to = c("data", "locations", "params", "datasets", "columns"),
warn_missing = TRUE
)rename_params_base(
md,
...,
apply_to = c("data", "params"),
warn_missing = TRUE
)
rename_locations_base(
md,
...,
apply_to = c("data", "locations"),
warn_missing = TRUE
)
# S3 method for mudata
rename_cols_base(
.data,
...,
apply_to = c("datasets", "locations", "params", "data", "columns"),
warn_missing = FALSE,
warn_duplicated = TRUE
)
A modified mudata object.
A mudata object
Key/value pairs in the form "oldvalue"="newvalue"
The tables which the rename operation should consider
Print a message if any old names are not actually present
A mudata object
Print a message if any name appears more than once in x after the operation.